@@ -10,9 +10,11 @@ import qualified GI.Xlib.Config as Xlib
 
 
 main :: IO ()
-main = setupBinding name version verbose overridesFile inheritedOverrides outputDir
+main = setupBinding name version pkgName pkgVersion verbose overridesFile inheritedOverrides outputDir
   where name = "GdkX11"
         version = "3.0"
+        pkgName = "gi-gdkx11"
+        pkgVersion = "3.0.12"
         overridesFile = Just "GdkX11.overrides"
         verbose = False
         outputDir = Nothing
